@@ -2,12 +2,13 @@ import argparse
 import basically_ti_basic as btb
 import os
 import tempfile
+import sys
 try:
 	from .tiParser import BasicParser
 except:
 	from tiParser import BasicParser
 
-def transpile(infile, outfile="stdout", decompileFile=True, forceDecompile=False):
+def transpile(infile, outfile="stdout", decompileFile=True, forceDecompile=False, run=False):
 
 	decode = os.path.splitext(infile)[1].lower() == ".8xp" and decompileFile == True
 
@@ -33,11 +34,22 @@ def transpile(infile, outfile="stdout", decompileFile=True, forceDecompile=False
 
 	# Write to outfile
 	if outfile == "stdout":
-		print("\n".join(pythonCode))
+		if run == False:
+			print("\n".join(pythonCode))
+		else:
+			temp_name = next(tempfile._get_candidate_names())
+			with open(temp_name, "w+") as f:
+				for line in pythonCode:
+					f.write(line + "\n")
+				f.seek(0)
+				os.system(sys.executable + " " + temp_name)
+			os.remove(temp_name)
 	else:
 		with open(outfile, 'w') as f:
 			for line in pythonCode:
 				f.write(line + "\n")
+		if run == True:
+			os.system(sys.executable + " " + outfile)
 
 def main():
 	parser = argparse.ArgumentParser()
@@ -67,9 +79,17 @@ def main():
 		dest="d"
 	)
 
+	parser.add_argument(
+		'-r',
+		'--run',
+		action="store_true",
+		help="Runs the program after it\'s done transpiling. Will not print to stdout",
+		dest='run'
+	)
+
 	args = parser.parse_args()
 
-	transpile(args.i, args.o, args.n, args.d)
+	transpile(args.i, args.o, args.n, args.d, args.run)
 
 
 if __name__ == "__main__":
